==> nextcloud-20.0.12.tgz: nextcloud/apps/weather_status/l10n/it.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Indirizzo sconosciuto",
    "No result." : "Nessun risultato.",
    "Malformed JSON data." : "Dati JSON non validi.",
    "Error" : "Errore",
    "Weather status" : "Stato meteo",
    "Weather status in your dashboard" : "Stato meteo nel tuo cruscotto",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Meteo integrato nell'applicazione del cruscotto.\n    La posizione dell'utente può essere determinata automaticamente o definita a mano. Vengono poi mostrate previsioni per 6 ore.\n    Questo stato può anche essere integrato in altri posti come nell'applicazione Calendario.",
    "Detect location" : "Elimina località",
    "Set custom address" : "Imposta indirizzo personalizzato",
    "Favorites" : "Preferiti",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Cielo sereno alle {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nuvoloso alle {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Giorno sereno alle {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Notte serena alle {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parzialmente nuvoloso alle {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebbioso alle {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Pioggia debole alle {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pioggia alle {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Pioggia intensa alle {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Piogge sparse alle {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Piogge deboli sparse alle {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Piogge intense sparse alle {time}",
    "More weather for {adr}" : "Altro meteo per {adr}",
    "Loading weather" : "Caricamento meteo",
    "Set location for weather" : "Imposta la località per il meteo",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add as favorite" : "Aggiungi come preferito",
    "You are not logged in." : "Accesso non effettuato.",
    "There was an error getting the weather status information." : "Si è verificato un errore durante il recupero delle informazioni meteo.",
    "No weather information found" : "Nessuna informazione meteo trovata",
    "Location not found" : "Località non trovata",
    "There was an error setting the location address." : "Si è verificato un errore impostando l'indirizzo della località.",
    "There was an error setting the location." : "Si è verificato un errore durante l'impostazione della località.",
    "There was an error saving the mode." : "Si è verificato un errore durante il salvataggio della modalità.",
    "There was an error using personal address." : "Si è verificato un errore usando l'indirizzo personale.",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Meteo integrato nell'applicazione del cruscotto.\n    La posizione dell'utente può essere determinata automaticamente o definita a mano. Vengono poi mostrate previsioni per 6 ore.\n    Questo stato può anche essere integrato in altri posti come nell'applicazione Calendario."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-21.0.8p0.tgz: nextcloud/apps/weather_status/l10n/it.js <==
OC.L10N.register(
    "weather_status",
    {
    "Unknown address" : "Indirizzo sconosciuto",
    "No result." : "Nessun risultato.",
    "Malformed JSON data." : "Dati JSON non validi.",
    "Error" : "Errore",
    "Weather status" : "Stato meteo",
    "Weather status in your dashboard" : "Stato meteo nel tuo cruscotto",
    "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Meteo integrato nell'applicazione del cruscotto.\n    La posizione dell'utente può essere determinata automaticamente o definita a mano. Vengono poi mostrate previsioni per 6 ore.\n    Questo stato può anche essere integrato in altri posti come nell'applicazione Calendario.",
    "Detect location" : "Elimina località",
    "Set custom address" : "Imposta indirizzo personalizzato",
    "Favorites" : "Preferiti",
    "More weather for {adr}" : "Altro meteo per {adr}",
    "Loading weather" : "Caricamento meteo",
    "Remove from favorites" : "Rimuovi dai preferiti",
    "Add as favorite" : "Aggiungi come preferito",
    "You are not logged in." : "Accesso non effettuato.",
    "There was an error getting the weather status information." : "Si è verificato un errore durante il recupero delle informazioni meteo.",
    "No weather information found" : "Nessuna informazione meteo trovata",
    "Location not found" : "Località non trovata",
    "There was an error setting the location address." : "Si è verificato un errore impostando l'indirizzo della località.",
    "There was an error setting the location." : "Si è verificato un errore durante l'impostazione della località.",
    "There was an error saving the mode." : "Si è verificato un errore durante il salvataggio della modalità.",
    "There was an error using personal address." : "Si è verificato un errore usando l'indirizzo personale.",
    "Set location for weather" : "Imposta la località per il meteo",
    "Weather status integrated in the dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Meteo integrato nell'applicazione del cruscotto.\n    La posizione dell'utente può essere determinata automaticamente o definita a mano. Vengono poi mostrate previsioni per 6 ore.\n    Questo stato può anche essere integrato in altri posti come nell'applicazione Calendario.",
    "{temperature} {unit} Clear sky at {time}" : "{temperature} {unit} Cielo sereno alle {time}",
    "{temperature} {unit} Cloudy at {time}" : "{temperature} {unit} Nuvoloso alle {time}",
    "{temperature} {unit} Fair day at {time}" : "{temperature} {unit} Giorno sereno alle {time}",
    "{temperature} {unit} Fair night at {time}" : "{temperature} {unit} Notte serena alle {time}",
    "{temperature} {unit} Partly cloudy at {time}" : "{temperature} {unit} Parzialmente nuvoloso alle {time}",
    "{temperature} {unit} Foggy at {time}" : "{temperature} {unit} Nebbioso alle {time}",
    "{temperature} {unit} Light rain at {time}" : "{temperature} {unit} Pioggia debole alle {time}",
    "{temperature} {unit} Rain at {time}" : "{temperature} {unit} Pioggia alle {time}",
    "{temperature} {unit} Heavy rain at {time}" : "{temperature} {unit} Pioggia intensa alle {time}",
    "{temperature} {unit} Rain showers at {time}" : "{temperature} {unit} Piogge sparse alle {time}",
    "{temperature} {unit} Light rain showers at {time}" : "{temperature} {unit} Piogge deboli sparse alle {time}",
    "{temperature} {unit} Heavy rain showers at {time}" : "{temperature} {unit} Piogge intense sparse alle {time}"
},
"nplurals=2; plural=(n != 1);");
